@@ -5,9 +5,13 @@
 
 #include <QStandardItemModel>
 #include <QDebug>
+#include <QDesktopServices>
 
 #include "roleitemmodel.h"
+#include "platutil.h"
+#include <QProcess>
 
+#include <QDesktopServices>
 
 RedditModel::RedditModel(QObject *parent) :
     QObject(parent)
@@ -22,6 +26,7 @@ RedditModel::RedditModel(QObject *parent) :
     roleNames[RedditEntry::ScoreRole] = "score";
     roleNames[RedditEntry::PermalaLinkRole] = "permalink";
     roleNames[RedditEntry::ThumbnailRole] = "thumbnail";
+    roleNames[RedditEntry::CommentsRole] = "comments";
 
     m_linksmodel = new RoleItemModel(roleNames);
 
@@ -67,6 +72,7 @@ void RedditModel::doPopulateLinks()
         it->setData(e.permalink, RedditEntry::PermalaLinkRole);
         it->setData(e.url, RedditEntry::UrlRole);
         it->setData(e.thumbnail, RedditEntry::ThumbnailRole);
+        it->setData(e.comments, RedditEntry::CommentsRole);
 
         m_linksmodel->appendRow(it);
 
@@ -119,3 +125,31 @@ void RedditModel::refreshCategories()
     }
 }
 
+void RedditModel::editConfig()
+{
+    QString cf = PlatUtil::configFile();
+#ifdef Q_WS_MAEMO_5
+
+    QString cmd = QString("/usr/bin/osso-xterm -e \"vi %1\"").arg(cf);
+#else
+    QString cmd = QString("/usr/bin/gedit \"vi %1\"").arg(cf);
+#endif
+
+    QProcess* p = new QProcess(this);
+    p->start(cmd);
+    p->waitForFinished();
+    delete p;
+
+}
+
+void RedditModel::browser(const QString &url)
+{
+    qDebug() << "browser " << url;
+    if (url.isEmpty()) {
+        QDesktopServices::openUrl(QUrl("http://reddit.com"));
+    } else {
+        QDesktopServices::openUrl(url);
+    }
+
+}
+
